<?php

declare(strict_types=1);

namespace Drupal\smsgateway_msg91\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\smsgateway_msg91\EmailTemplatesInterface;

/**
 * Defines the sms templates entity class.
 *
 * @ContentEntityType(
 *   id = "smsgateway_msg91_email_templates",
 *   label = @Translation("Sms Templates"),
 *   label_collection = @Translation("Sms Templatess"),
 *   label_singular = @Translation("sms templates"),
 *   label_plural = @Translation("sms templates"),
 *   label_count = @PluralTranslation(
 *     singular = "@count sms templates",
 *     plural = "@count sms templates",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\smsgateway_msg91\EmailTemplatesListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "form" = {
 *       "add" = "Drupal\smsgateway_msg91\Form\EmailTemplatesForm",
 *       "edit" = "Drupal\smsgateway_msg91\Form\EmailTemplatesForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *       "delete-multiple-confirm" = "Drupal\Core\Entity\Form\DeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "smsgateway_msg91_email_templates",
 *   admin_permission = "administer smsgateway_msg91_email_templates",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "id",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "collection" = "/admin/content/email-templates",
 *     "add-form" = "/email-templates/add",
 *     "canonical" = "/email-templates/{smsgateway_msg91_email_templates}",
 *     "edit-form" = "/email-templates/{smsgateway_msg91_email_templates}/edit",
 *     "delete-form" = "/email-templates/{smsgateway_msg91_email_templates}/delete",
 *     "delete-multiple-form" = "/admin/content/email-templates/delete-multiple",
 *   },
 *   field_ui_base_route = "entity.smsgateway_msg91_email_templates.settings",
 * )
 */
final class EmailTemplates extends ContentEntityBase implements EmailTemplatesInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['templateName'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Template Name'))
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => 0,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'type' => 'string_textfield',
        'label' => 'above',
        'weight' => 0,
      ])
      ->setDisplayConfigurable('view', TRUE);
    
    $fields['templateId'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Template Id'))
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => 10,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'type' => 'string_textfield',
        'label' => 'above',
        'weight' => 10,
      ])
      ->setDisplayConfigurable('view', TRUE);
    
    
    $fields['description'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Description'))
      ->setDisplayOptions('form', [
        'type' => 'text_textarea',
        'weight' => 15,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'type' => 'text_default',
        'label' => 'above',
        'weight' => 15,
      ])
      ->setDisplayConfigurable('view', TRUE);
    
    
    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Status'))
      ->setDefaultValue(TRUE)
      ->setSetting('on_label', 'Enabled')
      ->setDisplayOptions('form', [
        'type' => 'boolean_checkbox',
        'settings' => [
          'display_label' => FALSE,
        ],
        'weight' => 20,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'type' => 'boolean',
        'label' => 'above',
        'weight' => 20,
        'settings' => [
          'format' => 'enabled-disabled',
        ],
      ])
      ->setDisplayConfigurable('view', TRUE);

    return $fields;
  }

}
