<?php

namespace Drupal\smsgateway_msg91\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\paragraphs\Entity\Paragraph;
use Drupal\paragraphs\Entity\ParagraphsType;
use Drupal\Core\Entity\EntityFieldManager;

/**
 * Presents the module settings form.
 */
class MSGAPISettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'msgapi_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['msgapi.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('msgapi.settings');
    $form['msgapi_auth_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('MSG91 Auth URL'),
      '#default_value' => $config->get('msgapi_auth_url'),
      '#description' => 'Enter Auth URL',
      '#required' => TRUE,
    ];
    
    $form['msgapi_authKey'] = [
      '#type' => 'textfield',
      '#title' => $this->t('MSG91 Authentication ID'),
      '#default_value' => $config->get('msgapi_authKey'),
      '#required' => TRUE,
    ];

    $form['msgapi_template_Id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('MSG91 template ID'),
      '#default_value' => $config->get('msgapi_template_Id'),
      '#description' => 'Template ID for the Message',
      '#required' => TRUE,
    ];
    
    $form['msgapi_country'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Country Code'),
      '#default_value' => ($config->get('msgapi_country'))?$config->get('msgapi_country'):'91',
      '#required' => TRUE,
    ];

    $form['msgapi_short_url'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('MSG91 Short URL'),
      '#default_value' => $config->get('msgapi_short_url'),
      '#description' => 'On(1) /  Off(0)',
      '#required' => TRUE,
    ];
    
    $form['msgapi_realTimeResponse'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Real Time Response'),
      '#default_value' => $config->get('msgapi_realTimeResponse'),
      '#description' => 'On(1) /  Off(0)',
      '#required' => TRUE,
    ];
    
    return parent::buildForm($form, $form_state);

  }
  
   

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $route = $form_state->getValue('msgapi_short_url');
    $auth_key = $form_state->getValue('msgapi_authKey');
    $msg91auth_url = $form_state->getValue('msgapi_auth_url');
    $sender_id = $form_state->getValue('msgapi_template_Id');
    $realTimeResponse = $form_state->getValue('msgapi_realTimeResponse');
    $country = $form_state->getValue('msgapi_country');
    
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('msgapi.settings')
      ->set('msgapi_authKey', $form_state->getValue('msgapi_authKey'))
      ->set('msgapi_template_Id', $form_state->getValue('msgapi_template_Id'))
      ->set('msgapi_short_url', $form_state->getValue('msgapi_short_url'))
      ->set('msgapi_auth_url', $form_state->getValue('msgapi_auth_url'))
      ->set('msgapi_country', $form_state->getValue('msgapi_country'))
      ->set('msgapi_realTimeResponse', $form_state->getValue('msgapi_realTimeResponse'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
