<?php

namespace Drupal\smsgateway_msg91;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactory;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\RequestException;



/**
 * Class MSG91SMSService.
 */
class MSG91SMSService {

  /**
   * Drupal\Core\Config\ConfigFactoryInterface definition.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The HTTP client to fetch the feed data with.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * A logger instance.
   *
   * @var Drupal\Core\Logger\LoggerChannelFactory
   */
  protected $logger;

/**
 * 
 * @param ConfigFactoryInterface $config_factory
 * @param ClientInterface $http_client
 * @param LoggerChannelFactory $logger
 */
  public function __construct(ConfigFactoryInterface $config_factory, ClientInterface $http_client, LoggerChannelFactory $logger) {
    $this->configFactory = $config_factory->get('msgapi.settings');
    $this->httpClient = $http_client;
    $this->logger = $logger->get('smsgateway_msg91');
  }

/**
 * @param type $mobile_number
 * @param type $message
 * @param type $template_id
 * @param type $api_url
 * @param type $short_url
 * @return bool
 */
  public function msg91_send_message($mobile_number, $message, $template_id='',$tempVar) {
      
    if (empty($tempVar['mobiles'])) {
      $this->logger->error('Please provide a valid mobile number for sending SMS.');
      return FALSE;
    }
    
   //Get Configuration Detail
    $short_url = $this->configFactory->get('msgapi_short_url');
    $api_url = $this->configFactory->get('msgapi_auth_url');
    $auth_key = $this->configFactory->get('msgapi_authKey');
    $realTimeResponse = $this->configFactory->get('msgapi_realTimeResponse');
    $country = $this->configFactory->get('msgapi_country');
    
    // Remove "+91" or "91" from the beginning of the mobile number
    if (!empty($tempVar['mobiles'])) {
        $tempVar['mobiles'] = preg_replace('/^\+?91/', '', $tempVar['mobiles']);
    }
    
    if(!empty($tempVar['mobiles']) && !empty($country)){
        $tempVar['mobiles']=$country.$tempVar['mobiles'];
    }
   

    $request_data = [
      "template_id" => $template_id,
      "short_url" => $short_url,            
      "realTimeResponse" => $realTimeResponse,
      "recipients" => [$tempVar]
    ];

    try {
        $headers = ['authkey' => $auth_key, 'accept' => 'application/json', 'Content-Type' => 'application/json'];
        $request = $this->httpClient->post($api_url, ['body' => json_encode($request_data), 'headers' => $headers]);    
        $response = json_decode($request->getBody());
        return $response->type;
    } catch (Exception $exc) {
        echo $exc->getTraceAsString();
        die;
    }


 

    
  }

}
