<?php 
namespace Drupal\smsgateway_msg91\Plugin\Action;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Action\ConfigurableActionBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Datetime\DateFormatter;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\smsgateway_msg91\EcaManager;

/**
 * Sms Template Form Action
 *
 * @Action(
 *   id = "ttn_custom_email_template_action",
 *   label = @Translation("Sms Template Form"),
 *   type = "node"
 * )
 */
final class SendMsg91SMSTemplate extends ConfigurableActionBase implements ContainerFactoryPluginInterface {

  /**
   * @var string
   */
  protected $entity_type = "booking_entity";

  /**
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * @var \Drupal\Core\Datetime\DateFormatter
   */
  protected $dateFormatter;

  /**
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $loggerFactory;

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeInterface;

  /**
   * ConvertEnquiryToBooking constructor.
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   * @param ConfigFactoryInterface $config_factory
   * @param AccountInterface $account
   * @param DateFormatter $date_formatter
   * @param LoggerChannelFactoryInterface $logger_factory
   * @param EntityTypeManagerInterface $entity_type_manager
   * @param TimeInterface $time_interface
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    ConfigFactoryInterface $config_factory,
    AccountInterface $account,
    DateFormatter $date_formatter,
    LoggerChannelFactoryInterface $logger_factory,
    EntityTypeManagerInterface $entity_type_manager,
    TimeInterface $time_interface,
    EcaManager $ecaManager
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
    $this->account = $account;
    $this->dateFormatter = $date_formatter;
    $this->loggerFactory = $logger_factory->get('custom_actions');
    $this->entityTypeManager = $entity_type_manager;
    $this->timeInterface = $time_interface;
   // $this->currentUser = $account;
    $this->ecaManager = $ecaManager;
  }

  /**
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   *
   * @return static
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('current_user'),
      $container->get('date.formatter'),
      $container->get('logger.factory'),
      $container->get('entity_type.manager'),
      $container->get('datetime.time'),
      $container->get('smsgateway_msg91.eca_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
  //  dump($this->configuration);
  
  
    try {
        
      $token_name=  $this->configuration['smsTemplate'];
  $object =  $this->configuration['object'];
  $data[$object]=$token_name;
  $this->setConfiguration($data);
  //return $this->configuration['smsTemplate'];
  
    } catch(EntityStorageException $e) {
      $this->messenger()->addError($this->t('There was a problem updating the booking status, please try again later.'));
      $this->loggerFactory->error('%errormsg %errorstack', ['%errormsg' => $e->getMessage(), '%errorstack' => $e->getTraceAsString()]);
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getDefaultConfiguration()
  {
    return [
      'smsTemplate' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function access($node, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\node\NodeInterface $node */
    $access = $node->access('update', $account, TRUE)
      ->andIf($node->title->access('edit', $account, TRUE));
    return $return_as_object ? $access : $access->isAllowed();
  }

  /**
   * @inheritDoc
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state){

    // Fetch dynamic options.
    $options = $this->getSmsTemplateOptions();

//    $form['smsTemplate'] = [
//    '#type' => 'select',
//    '#title' => t('SMS Template'),
//    '#description' => t('This is the SMS template selection to send SMS'),
//    '#default_value' => $this->configuration['smsTemplate'],
//    '#options' => $options,
//    '#required' => TRUE,
//    ];
    
    
    return $form;
  }
  

  /**
   * @inheritDoc
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state){
      
      $this->configuration['smsTemplate'] = $form_state->getValue('smsTemplate');
         \Drupal::state()->set('smsgateway_msg91.selected_sms_template', $this->configuration['smsTemplate']);
     // $action_config = $this->ecaManager->setActionConfigTemplate($this->configuration['smsTemplate']);
    // $this->configuration['template_value'] = $form_state->getValue('template_value');
    //  $action_config = $this->ecaManager->setActionConfigTemplate($this->configuration['template_value'],$this->configuration['smsTemplate']);
 

  }
  
  /**
 * Get SMS template options.
 *
 * @return array
 *   An associative array of SMS template options.
 */
protected function getSmsTemplateOptions() {
    $database = \Drupal::database();
    $query = $database->query("SELECT id,templateName FROM {smsgateway_msg91_email_templates}  WHERE status=1");
    $result = $query->fetchAll();
    $options=[];
    if(!empty($result)){
        foreach ($result as $data) {
            $options[$data->id] = $data->templateName;
        }
    }
    return $options;
}




}